===========================================
`Python Artificial Intelligence Framework`_
===========================================

Copyright (c) 2014,2015,2016,2017 Jeremie DECOCK (http://www.jdhp.org)

* Web site: http://www.jdhp.org/software_en.html#pyai
* Online documentation: http://pyai.readthedocs.org
* Source code: https://github.com/jeremiedecock/pyai
* Issue tracker: https://github.com/jeremiedecock/pyai/issues
* pyai on PyPI: https://pypi.python.org/pypi/jdhp-pyai


Description
===========

This is a set of open source frameworks for Artificial Intelligence
(mostly machine learning and optimization).

This contains (among others):

-  a blackbox non linear noisy optimization framework;
-  a machine learning framework;
-  a multistage optimization and Markov Decision Process framework
   (Markov Decision Processes).

Note:

    This project is still in beta stage, so the API is not finalized yet.


Dependencies
============

-  Python >= 3.0
-  Numpy
-  Matplotlib

.. _install:

Installation
============

Gnu/Linux
---------

You can install, upgrade, uninstall PyAI with these commands (in a
terminal)::

    pip install --pre jdhp-pyai
    pip install --upgrade jdhp-pyai
    pip uninstall jdhp-pyai

Or, if you have downloaded the PyAI source code::

    python3 setup.py install

.. There's also a package for Debian/Ubuntu::
.. 
..     sudo apt-get install jdhp-pyai

Windows
-------

.. Note:
.. 
..     The following installation procedure has been tested to work with Python
..     3.4 under Windows 7.
..     It should also work with recent Windows systems.

You can install, upgrade, uninstall PyAI with these commands (in a
`command prompt`_)::

    py -m pip install --pre jdhp-pyai
    py -m pip install --upgrade jdhp-pyai
    py -m pip uninstall jdhp-pyai

Or, if you have downloaded the PyAI source code::

    py setup.py install

MacOSX
-------

.. Note:
.. 
..     The following installation procedure has been tested to work with Python
..     3.5 under MacOSX 10.9 (*Mavericks*).
..     It should also work with recent MacOSX systems.

You can install, upgrade, uninstall PyAI with these commands (in a
terminal)::

    pip install --pre jdhp-pyai
    pip install --upgrade jdhp-pyai
    pip uninstall jdhp-pyai

Or, if you have downloaded the PyAI source code::

    python3 setup.py install


Documentation
=============

* Online documentation: http://pyai.readthedocs.org
* API documentation: http://pyai.readthedocs.org/en/latest/api.html


Example usage
=============

TODO


Bug reports
===========

To search for bugs or report them, please use the PyAI Bug Tracker at:

    https://github.com/jeremiedecock/pyai/issues


License
=======

This project is provided under the terms and conditions of the `MIT License`_.


.. _MIT License: http://opensource.org/licenses/MIT
.. _command prompt: https://en.wikipedia.org/wiki/Cmd.exe
.. _Python Artificial Intelligence Framework: http://www.jdhp.org/projects_en.html#pyai
